import{h as c,o as _,c as l,d as t,b as e,q as d,w as s,D as m,y as p,e as o,bD as u}from"./CBR445J6.js";import{_ as g}from"./CrZjGMUk.js";import{u as f}from"./CWZa5uCX.js";import{_ as h}from"./BWgDgmdD.js";const x={class:"grid items-start lg:grid-cols-5"},b={class:"grid grid-cols-1 lg:col-span-4 bg-backdrop dark:bg-backdrop-dark"},k={class:"text-center"},y=e("h1",{class:"font-semibold mb-16 text-5xl"}," Strategies ",-1),S={class:"mb-4"},N=c({__name:"index",setup(v){return f({title:"Strategies - Jesse"}),(a,r)=>{const n=p,i=g;return _(),l("section",x,[t(h),e("div",b,[e("div",{class:"flex items-center justify-center select-none",style:d({height:"calc(100vh - 4rem - 4px)"})},[e("div",k,[y,e("div",S,[t(n,{icon:"i-heroicons-plus",onClick:r[0]||(r[0]=B=>("useTempStore"in a?a.useTempStore:m(u))().makeStrategy=!0)},{default:s(()=>[o(" Create a new strategy ")]),_:1}),t(i,{class:"my-6 text-xs"},{default:s(()=>[o(" OR ")]),_:1}),t(n,{icon:"i-heroicons-link",color:"gray",to:"https://jesse.trade/strategies",target:"_blank"},{default:s(()=>[o(" Browse free and premium strategies ")]),_:1})])])],4)])])}}});export{N as default};
